@@ -16,25 +16,25 @@ import kfp.dsl as dsl
 import kfp
 
 
-def list_gcs(s: str):
+def main_coon(s: str):
     container_op = dsl.ContainerOp(
         name='main-coon',
         image='eu.gcr.io/second-capsule-253207/adlinear:latest',
         command=['python'],
         arguments=['main_coon.py']
     )
-    container_op.add_resource_limit("memory", '100M')
-    container_op.add_resource_limit("cpu", '.1')
-    container_op.add_resource_request("memory", '100M')
-    container_op.add_resource_request("cpu", '.1')
+    container_op.add_resource_limit("memory", '5G')
+    container_op.add_resource_limit("cpu", '3')
+    container_op.add_resource_request("memory", '5G')
+    container_op.add_resource_request("cpu", '3')
     return container_op
 
 
-@dsl.pipeline(name='list-gcs-buckets')
+@dsl.pipeline(name='main-coon')
 def pipeline():
     loop_args = list(range(3))
     with dsl.ParallelFor(loop_args, parallelism=10) as item:
-        list_gcs(item)
+        main_coon(item)
 
 
 if __name__ == '__main__':
