@@ -6,14 +6,40 @@ import pandas as pd
 from nptyping import NDArray
 from typing import Callable, Any, Union, Tuple, Dict
 from typing import Dict
-from adlinear import testers as tst
 from adlinear import utilities as utl
 from adlinear import nmfmodel as nmf
-from pathlib import Path
 import root_path
 import dotenv
+from transparentpath import TransparentPath
+import random
+TransparentPath.set_global_fs("gcs", bucket="nmf_experiments_dev", token="cred_gcs.json")
 dotenv.load_dotenv()
 
+arange = list((0, int(1e6)))
+
+
+class RandomNamedFile:
+
+    def __init__(self, dirpath: TransparentPath, root_name: str, suffix: str):
+        self.dirpath = dirpath
+        self.filepath = None
+        number = random.randint(*arange)
+        filepath = (dirpath / f"{root_name}_{number}").with_suffix(suffix)
+        attempts = 0
+        while filepath.is_file():
+            if attempts > 99:
+                # Failed to create a unique file
+                return
+            number += 1
+            attempts += 1
+            if number in arange:
+                arange.remove(number)
+            number = random.randint(*arange)
+            filepath = (dirpath / f"{root_name}_{number}").with_suffix(suffix)
+
+        self.filepath = filepath
+        self.filepath.touch()
+
 
 class RandomVariable:
 
